@@ -1036,7 +1036,7 @@
 		tmp = .Call("marmaxsim", model = as.integer(modelinc[1:21]), 
 				pars = as.numeric(ipars[,1]), idx = as.integer(idx[,1]-1), 
 				mu = constm, x = x, res = ans$res, N = as.integer( c(m, n) ), 
-				PACKAGE = "rugarch", DUP = FALSE)
+				PACKAGE = "rugarch")
 		seriesSim = matrix(tmp$x[(n.start + m + 1):(n+m), ], ncol = m.sim)
 	}
 	
@@ -1369,7 +1369,7 @@
 	ans = .Call("mgjrgarchsim", model = as.integer(modelinc[1:21]), 
 			pars = as.numeric(ipars[,1]), idx = as.integer(idx[,1]-1), 
 			h = h, z = z, res = res, e = e, nres = nres, nindx = nindx, 
-			vxs = vxs, N = as.integer( c(m, n) ), PACKAGE = "rugarch", DUP = FALSE)
+			vxs = vxs, N = as.integer( c(m, n) ), PACKAGE = "rugarch")
 	
 	sigmaSim = matrix(sqrt( ans$h[(n.start + m + 1):(n+m), ] ), ncol = m.sim)
 	residSim = matrix(ans$res[(n.start + m + 1):(n+m), ], ncol = m.sim)
